# SR Box

L'item SR (serial response) box collecte les réponses issues d'une button box connectée à un port série ou via USB à un port de série virtuel. Cet item peut être utilisé avec la SR Box (Psychology Software Tools, Inc.) et les dispositifs compatibles.

## Mode factice

Dans le mode factice, la SR box est simulée par les touches numériques du clavier. Ce mode est pratique lorsque vous voulez tester votre expérimentation sans SR box.

## Ignorer les boutons qui ont déjà été pressés

Si vous autorisez l'option "Ignorer les boutons déjà appuyés", le plugin répondra uniquement aux boutons qui vont de 'ne pas être pressés' à 'être pressés'. C'est généralement ce qui est demandé, parce que ça évite qu'un seul bouton pressé déclenche une série de réponses à lui seul. Cependant, cette option es désactivée par défaut pour des raisons de compatibilité.

## Noms des boutons et lumières

Les boutons et les lumières sont identifiés par un chiffre entre 1 et 8. Le nombre de boutons et la correspondance entre un bouton et un chiffre dépend de votre button box. La SR Box vendue par Psychology Software Tools, Inc. contient 5 boutons et 5 lumières, le bouton 1 et la lumière 1 étant disposés à gauche. Les lumières peuvent ne pas être disponibles avec d'autres SR boxes, dans ce cas elles sont ignorées.

## Informations supplémentaires

Sur le site Psychology Software Tools:

- <http://www.pstnet.com/hardware.cfm?ID=102>.

Sur la documentation du site OpenSesame :

- <http://osdoc.cogsci.nl/3.2/manual/response/srbox/>
